@@ -10,7 +10,7 @@ def daily_growth_rate(df, col_name):
     df : pandas DataFrame
         Data frame with date and price data.
     col_name: str
-        Name of the column holding daily ending price data. 
+        Name of the column holding daily closing price data. 
 
     Returns
     -------
@@ -19,7 +19,7 @@ def daily_growth_rate(df, col_name):
 
     Examples
     -------
-    >>> daily_growth_rate(price_df, closing_price)
+    >>> daily_growth_rate(price_df, 'Close')
                
     """
     # Test whether input data is of pd.DataFrame type
@@ -33,9 +33,10 @@ def daily_growth_rate(df, col_name):
     # Test whether input col_name is of type numbers
     if df[col_name].dtype != np.float64:
         raise TypeError("input col_name must be of float type")
-    
+   
+    df["daily_growth_rate(%)"] = df[col_name].pct_change()*100
         
-    return  pd.DataFrame({"daily_growth_rate": df[col_name].pct_change()})
+    return  df
     
     
     
